@@ -128,58 +128,64 @@ auto CCMArgs = r::List::create(
     r::_["parameterList"]   = false,
     r::_["verbose"]         = false );
     
-auto EmbedDimensionArgs = r::List::create( 
-    r::_["pathIn"]      = std::string("./"),
-    r::_["dataFile"]    = std::string(""),
-    r::_["dataFrame"]   = r::DataFrame(),
-    r::_["pathOut"]     = std::string("./"),
-    r::_["predictFile"] = std::string(""),
-    r::_["lib"]         = std::string(""),
-    r::_["pred"]        = std::string(""),
-    r::_["maxE"]        = 10,
-    r::_["Tp"]          = 1,
-    r::_["tau"]         = -1,
-    r::_["columns"]     = std::string(""),
-    r::_["target"]      = std::string(""),
-    r::_["embedded"]    = false,
-    r::_["verbose"]     = false,
-    r::_["numThreads"]  = 4 );
+auto EmbedDimensionArgs     = r::List::create( 
+    r::_["pathIn"]          = std::string("./"),
+    r::_["dataFile"]        = std::string(""),
+    r::_["dataFrame"]       = r::DataFrame(),
+    r::_["pathOut"]         = std::string("./"),
+    r::_["predictFile"]     = std::string(""),
+    r::_["lib"]             = std::string(""),
+    r::_["pred"]            = std::string(""),
+    r::_["maxE"]            = 10,
+    r::_["Tp"]              = 1,
+    r::_["tau"]             = -1,
+    r::_["exclusionRadius"] = 0,
+    r::_["columns"]         = std::string(""),
+    r::_["target"]          = std::string(""),
+    r::_["embedded"]        = false,
+    r::_["verbose"]         = false,
+    r::_["validLib"]        = std::vector<bool>(),
+    r::_["numThreads"]      = 4 );
 
 auto PredictIntervalArgs = r::List::create( 
-    r::_["pathIn"]      = std::string("./"),
-    r::_["dataFile"]    = std::string(""),
-    r::_["dataFrame"]   = r::DataFrame(),
-    r::_["pathOut"]     = std::string("./"),
-    r::_["predictFile"] = std::string(""),
-    r::_["lib"]         = std::string(""),
-    r::_["pred"]        = std::string(""),
-    r::_["maxTp"]       = 10,
-    r::_["E"]           = 0,
-    r::_["tau"]         = -1,
-    r::_["columns"]     = std::string(""),
-    r::_["target"]      = std::string(""),
-    r::_["embedded"]    = false,
-    r::_["verbose"]     = false,
-    r::_["numThreads"]  = 4 );
+    r::_["pathIn"]          = std::string("./"),
+    r::_["dataFile"]        = std::string(""),
+    r::_["dataFrame"]       = r::DataFrame(),
+    r::_["pathOut"]         = std::string("./"),
+    r::_["predictFile"]     = std::string(""),
+    r::_["lib"]             = std::string(""),
+    r::_["pred"]            = std::string(""),
+    r::_["maxTp"]           = 10,
+    r::_["E"]               = 0,
+    r::_["tau"]             = -1,
+    r::_["exclusionRadius"] = 0,
+    r::_["columns"]         = std::string(""),
+    r::_["target"]          = std::string(""),
+    r::_["embedded"]        = false,
+    r::_["verbose"]         = false,
+    r::_["validLib"]        = std::vector<bool>(),
+    r::_["numThreads"]      = 4 );
 
 auto PredictNonlinearArgs = r::List::create( 
-    r::_["pathIn"]      = std::string("./"),
-    r::_["dataFile"]    = std::string(""),
-    r::_["dataFrame"]   = r::DataFrame(),
-    r::_["pathOut"]     = std::string("./"),
-    r::_["predictFile"] = std::string(""),
-    r::_["lib"]         = std::string(""),
-    r::_["pred"]        = std::string(""),
-    r::_["theta"]       = std::string(""),
-    r::_["E"]           = 0,
-    r::_["Tp"]          = 1,
-    r::_["knn"]         = 0,
-    r::_["tau"]         = -1,
-    r::_["columns"]     = std::string(""),
-    r::_["target"]      = std::string(""),
-    r::_["embedded"]    = false,
-    r::_["verbose"]     = false,
-    r::_["numThreads"]  = 4 );
+    r::_["pathIn"]          = std::string("./"),
+    r::_["dataFile"]        = std::string(""),
+    r::_["dataFrame"]       = r::DataFrame(),
+    r::_["pathOut"]         = std::string("./"),
+    r::_["predictFile"]     = std::string(""),
+    r::_["lib"]             = std::string(""),
+    r::_["pred"]            = std::string(""),
+    r::_["theta"]           = std::string(""),
+    r::_["E"]               = 0,
+    r::_["Tp"]              = 1,
+    r::_["knn"]             = 0,
+    r::_["tau"]             = -1,
+    r::_["exclusionRadius"] = 0,
+    r::_["columns"]         = std::string(""),
+    r::_["target"]          = std::string(""),
+    r::_["embedded"]        = false,
+    r::_["verbose"]         = false,
+    r::_["validLib"]        = std::vector<bool>(),
+    r::_["numThreads"]      = 4 );
 
 //-------------------------------------------------------------------------
 // Export / map the functions
