@@ -124,10 +124,12 @@ r::DataFrame PredictNonlinear_rcpp( std::string  pathIn,
                                     int          Tp,
                                     int          knn,
                                     int          tau,
+                                    int          exclusionRadius,
                                     std::string  columns,
                                     std::string  target,
                                     bool         embedded,
                                     bool         verbose,
+                                    std::vector<bool> validLib,
                                     unsigned     numThreads );
 
 r::DataFrame PredictInterval_rcpp( std::string  pathIn,
@@ -140,10 +142,12 @@ r::DataFrame PredictInterval_rcpp( std::string  pathIn,
                                    int          maxTp,
                                    int          E,
                                    int          tau,
+                                   int          exclusionRadius,
                                    std::string  columns,
                                    std::string  target,
                                    bool         embedded,
                                    bool         verbose,
+                                   std::vector<bool> validLib,
                                    unsigned     numThreads );
 
 r::DataFrame EmbedDimension_rcpp( std::string  pathIn,
@@ -156,10 +160,12 @@ r::DataFrame EmbedDimension_rcpp( std::string  pathIn,
                                   int          maxE,
                                   int          Tp,
                                   int          tau,
+                                  int          exclusionRadius,
                                   std::string  columns,
                                   std::string  target,
                                   bool         embedded,
                                   bool         verbose,
+                                  std::vector<bool> validLib,
                                   unsigned     numThreads );
 
 r::DataFrame Embed_rcpp( std::string  path,
